# Test Coverage Report

Generated: Thu 2013-02-28 16:32 SGT

| Statements
--- | ---
Module | total | executed | excluded | % covered
Total | 157 | 80 | 33 | 64.5%
multilingual_events.__init__ | 1 | 1 | 0 | 100.0%
multilingual_events.forms | 14 | 0 | 4 | 0.0%
multilingual_events.models | 108 | 57 | 20 | 64.8%
multilingual_events.simple_translate | 4 | 0 | 2 | 0.0%
multilingual_events.templatetags.multilingual_events_tags | 12 | 8 | 3 | 88.9%
multilingual_events.views | 18 | 14 | 4 | 100.0%

Excluded packages and modules
Error packages and modules